@@ -3,12 +3,13 @@ import json
 import logging
 import xml.etree.ElementTree as ET
 from collections import defaultdict
+from enum import Enum
 from pathlib import Path
 from typing import Dict, List
 
 import typer
 
-from snipsync.settings import CONFIG_TEMPLATE, USER_XML_TEMPLATE
+from snipsync.settings import CONFIG_TEMPLATE, USER_XML_TEMPLATE, IdeEnum
 from snipsync.ultisnip import UltiSnipsFileSource
 from snipsync.xml_snippet import XmlSnippet, read_ultisnips
 
@@ -22,7 +23,7 @@ APP_NAME = "snipsync"
 def setup(
     ctx: typer.Context,
 ):
-    """ Global setup """
+    """Global setup"""
     app_dir = typer.get_app_dir(APP_NAME)
     ctx.obj = dict(
         app_dir=Path(app_dir),
@@ -34,9 +35,9 @@ def setup(
 @app.command()
 def dir(
     ctx: typer.Context,
-):
+):  # pragma: no cover
     """
-    Show the location of the configuration file
+    Open/create configuration file for potential adjustment.
     """
     app_dir = ctx.obj.get("app_dir")
     config_path = ctx.obj.get("config_path")
@@ -81,6 +82,52 @@ def parse_config(config_path) -> Dict:
     return cfg
 
 
+def check_intellij_installation(p: Path) -> bool:
+    """
+    Check whether valid and latest InteliJ IDE is target for user.xml
+    :param p: path to the user.xml
+    :raises if not valid or outdated
+    """
+    if not p.is_dir():
+        typer.secho(f"{p} is not a valid directory.", color=typer.colors.RED)
+        raise typer.Abort()
+
+    for ide in IdeEnum:
+        if ide.value.lower() in str(p).lower():
+            break
+    else:
+        typer.secho(
+            f"Given path {p} invalid. Mus contain one of: {[ide.value for ide in IdeEnum]}",
+            color=typer.colors.RED,
+        )
+        raise typer.Abort()
+
+    root = f"{str(p).split('JetBrains')[0]}JetBrains"
+    GLOB = f"*"
+
+    dirs = [d for d in Path(root).glob(GLOB) if d.is_dir()]
+    dirs = [d for d in dirs if ide.value in str(d)]
+    if len(dirs) == 0:
+        typer.secho(
+            f"No installation {ide.value} found in {root}", color=typer.colors.RED
+        )
+        raise typer.Abort()
+
+    latest_installation = sorted(dirs)[-1]
+
+    if latest_installation not in p.parents:
+        typer.secho(
+            f"There seems to be a newer version of Intellij: {latest_installation} ",
+            color=typer.colors.RED,
+        )
+        typer.secho(
+            f"Please check your snipsync configuration.", color=typer.colors.RED
+        )
+        raise typer.Abort()
+
+    return True  # for pytest assertions
+
+
 @app.command()
 def auto_sync(
     ctx: typer.Context,
@@ -100,11 +147,11 @@ def auto_sync(
 
     typer.secho(f"-M- Configuration: {config_path}", fg=None)
     config = parse_config(config_path)
+    check_intellij_installation(config.get("live_templates_path"))
 
     # TODO: expand to work for arbitrary xml file not only user.xml
     user_xml_template_path = config.get("live_templates_path") / "user.xml"
     if config.get("init") or not Path(user_xml_template_path).is_file():
-
         typer.secho(f"-M- Initializing : {user_xml_template_path}", fg=None)
 
         with open(user_xml_template_path, "w") as textfile:
@@ -140,13 +187,14 @@ def sync(
     xmlsnip_file: Path = typer.Argument(..., help="xmlsnip target", exists=False),
 ):
     """
-    Synchronizes Ultisnip snippets to InteliJ Live Templates
+    Synchronizes Ultisnip snippets file to InteliJ Live Templates and sets the corresponding Live Template context
     """
     ultisnip_file = ultisnip_file.expanduser()
     if not ultisnip_file.exists():
         typer.secho(f"-E- Invalid UltiSnips source: {ultisnip_file}", fg="red")
         raise typer.Abort()
 
+    check_intellij_installation(xmlsnip_file.parent)
     xmlsnip_file = xmlsnip_file.expanduser()
 
     typer.secho(f"-M- Syncing {ultisnip_file} -> {xmlsnip_file}", fg=None)
