@@ -1,3 +1,5 @@
+from enum import Enum
+
 from snipsync.lexer import (
     ChoicesToken,
     EscapeCharToken,
@@ -22,6 +24,14 @@ ALLOWED_TOKENS = [
     ShellCodeToken,
 ]
 
+
+class IdeEnum(Enum):
+    PYCHARM = "PyCharm"
+    WEBSTORM = "WebStorm"
+    IDEAI = "IdeaI"
+    GOLAND = "GoLand"
+
+
 CONFIG_TEMPLATE = """\
 [DEFAULT]
 live_templates_path = ~/Library/Application Support/JetBrains/PyCharm2020.3/jba_config/templates
